//
//  WriteView.m
//  BarCodeScanning
//
//  Created by Yogesh Arora on 21/12/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "BarCodeFramework/WriteBarCode.h"
#import "WriteView.h"

#define MissingInfo     @"Missing Information"
#define FillAllFields   @"Please fill all fields"

#define ImageCreated    @"Image Created Successfully at path %@"
#define WrongFormat     @", Format of text not compatible with selected bar code"

@interface WriteView()

- (void) registerNotification;

@end

@implementation WriteView

- (id) initWithCoder:(NSCoder*)aDecoder
{
    if (self = [super initWithCoder:aDecoder])
    {
        //Setting default value of combobox
        [_barFormatCmb selectItemAtIndex:0];
    }
    return self;
}

#pragma Mark - Button Action
- (IBAction) writeBtnAction:(id)sender
{
    //check all field whether empty
    if (([_barTextTxt stringValue].length == 0) || /*([_imageExtTxt stringValue].length == 0) ||*/ ([_imageWidthTxt intValue] == 0) || ([_imageHeightTxt intValue] == 0) || ([_imageLocTxt stringValue].length == 0)) 
    {
        NSAlert* alert = [NSAlert alertWithMessageText:MissingInfo defaultButton:nil alternateButton:nil otherButton:nil informativeTextWithFormat:FillAllFields];
        [alert runModal]; 
    }
    else
    {
        [self registerNotification];
        [_imageCreatedLbl setStringValue:@"Progressing.........."];
        
        //start writing with parameters
        WriteBarCode* writeC = [[WriteBarCode alloc] init];
        
        //Setting all writing parameters
        writeC.text = [_barTextTxt stringValue];
        writeC.path = [_imageLocTxt stringValue];
        writeC.extension = @"jpg";
        writeC.format = [_barFormatCmb stringValue];
        writeC.width = [_imageWidthTxt intValue];
        writeC.height = [_imageHeightTxt intValue];
        
        //Call create image api
        [writeC createBCImage];
        [writeC release];
    }
}

- (IBAction) browserAction:(id)sender
{
    //Inializing save panel object
    NSSavePanel* panelObj = [NSSavePanel savePanel];
    NSInteger flag = [panelObj runModal];
    if(flag == NSOKButton)
    {
        //Assigning selected path to text field
        [_imageLocTxt setStringValue:[panelObj filename]];
    }
}

//Invoke when application recieved notification 
- (void) handleNotification:(NSNotification*)note
{
    if ([[[note object] objectForKey:@"Result"] isEqualToString:@"Ok"])
    {
        //Succeed
        [_imageCreatedLbl setStringValue:[NSString stringWithFormat:ImageCreated, [_imageLocTxt stringValue]]];
    }
    else
    {
        //Fail
        NSString* error = [NSString stringWithFormat:@"Error Code:%@",[[note object] valueForKey:@"Error_Code"]];
                
        if([[[note object] valueForKey:@"Error_Code"] intValue] == 506)
        {
            error = [error stringByAppendingFormat:WrongFormat];
        }
                     
        [_imageCreatedLbl setStringValue:error];

    }
    //Removing notification
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

#pragma Mark - Private Methods
//This method register the application to recieve notification for error and writing success
- (void) registerNotification
{
    //Register notifications
    [[NSNotificationCenter defaultCenter]  addObserver:self
                                              selector:@selector(handleNotification:)
                                                  name:@"NSNotificationWriteSuccess"
                                                object:nil];
    [[NSNotificationCenter defaultCenter]  addObserver:self
                                              selector:@selector(handleNotification:)
                                                  name:@"NSNotificationErrorRecieved"
                                                object:nil];
}

- (void) dealloc
{   
    [_barTextTxt release];
    [_imageLocTxt release];
    [_imageWidthTxt release];    
    [_imageHeightTxt release];
    [_imageCreatedLbl release];
    [_barFormatCmb release];
    
    [super dealloc];
}

@end
